[open-ils-commits] [GIT] Evergreen ILS branch rel_2_12 updated. c3d05cae76fee23ccc37e204217837d511d2882d

Evergreen Git git at git.evergreen-ils.org
Wed Nov 8 13:49:13 EST 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Evergreen ILS".

The branch, rel_2_12 has been updated
       via  c3d05cae76fee23ccc37e204217837d511d2882d (commit)
      from  920028d5ba34a07e5088519624896ce7b9750584 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit c3d05cae76fee23ccc37e204217837d511d2882d
Author: Mike Rylander <mrylander at gmail.com>
Date:   Wed Nov 1 18:22:21 2017 -0400

    LP#1704396: reset the facet alarm timer
    
    When using alarm() one must reset the timer via alarm(0) or incur the wrath
    of the spurious signal.
    
    Conflicts:
    	Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm
    
    Signed-off-by: Mike Rylander <mrylander at gmail.com>
    Signed-off-by: Jason Stephenson <jason at sigio.com>

diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm
index 670076b..a60b156 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm
@@ -1409,11 +1409,13 @@ sub retrieve_cached_facets {
 
     eval {
         local $SIG{ALRM} = sub {die};
-        alarm(2); # we'll sleep for as much as 2s
+        alarm(10); # we'll sleep for as much as 10s
         do {
             die if $cache->get_cache($key . '_COMPLETE');
         } while (sleep(0.05));
+        alarm(0);
     };
+    alarm(0);
 
     my $blob = $cache->get_cache($key) || {};
 

-----------------------------------------------------------------------

Summary of changes:
 .../lib/OpenILS/Application/Search/Biblio.pm       |    4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
Evergreen ILS


More information about the open-ils-commits mailing list